MultiPolygonGeometry

Struct MultiPolygonGeometry 

pub struct MultiPolygonGeometry(pub Vec<PolygonGeometry>);
Represents a collection of polygons, each of which may have an outer ring and optional inner holes. This struct is used for complex, multi-part areas in 2D space.

Tuple Fields

0: Vec<PolygonGeometry>